#ifndef _PY_MOD_SKIN_H_
#define _PY_MOD_SKIN_H_

void python_gc_skin_module_init(void);

#endif
